@@ -67,7 +67,7 @@ protected:
 
   boost::regex m_page_re1, m_page_re2, m_page_re3;
 
-  debugging_option_c m_debug;
+  debugging_option_c m_debug, m_debug_packet, m_debug_conversion;
 
 public:
   teletext_to_srt_packet_converter_c();
@@ -85,8 +85,10 @@ protected:
   bool decode_line(unsigned char const *buffer, unsigned int row_number);
   void process_single_row(unsigned int row_number);
   void decode_page_data(unsigned char ttx_header_magazine);
-  void deliver_queued_content();
+  void queue_page_content(std::string const &content);
   void queue_packet(packet_cptr const &new_packet);
+  void deliver_queued_packet();
+  bool maybe_merge_queued_and_new_packet(packet_t const &new_packet);
 
 protected:
   static int ttx_to_page(int ttx);
