@@ -1,5 +1,4 @@
-#ifndef MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_TIME_VALUE_PAGE_H
-#define MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_TIME_VALUE_PAGE_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -31,5 +30,3 @@ public:
 };
 
 }}}
-
-#endif  // MTX_MKVTOOLNIX_GUI_HEADER_EDITOR_TIME_VALUE_PAGE_H
