@@ -1,5 +1,6 @@
 #include "common/common_pch.h"
 
+#include <QFileInfo>
 #include <QMenu>
 
 #include "common/bitvalue.h"
@@ -341,13 +342,12 @@ Tab::onTitleChanged(QString newValue) {
 
 void
 Tab::setDestination(QString const &newValue) {
-  QString prefix;
 #if defined(SYS_WINDOWS)
-  if (newValue.startsWith(Q(":")))
-    prefix = Q(":");
+  if (!newValue.contains(QRegularExpression{Q("^[a-zA-Z]:[\\\\/]|^\\\\\\\\.+\\.+")}))
+    return;
 #endif
 
-  m_config.m_destination = QDir::toNativeSeparators(prefix + Util::removeInvalidPathCharacters(newValue));
+  m_config.m_destination = QDir::toNativeSeparators(Util::removeInvalidPathCharacters(newValue));
   if (!m_config.m_destination.isEmpty()) {
     auto &settings           = Util::Settings::get();
     settings.m_lastOutputDir = QFileInfo{ newValue }.absoluteDir();
@@ -358,7 +358,7 @@ Tab::setDestination(QString const &newValue) {
   if (m_config.m_destination == newValue)
     return;
 
-  auto newPosition = std::max(ui->output->cursorPosition(), 1) - 1;
+  auto newPosition = ui->output->cursorPosition();
   ui->output->setText(m_config.m_destination);
   ui->output->setCursorPosition(newPosition);
 }
@@ -368,6 +368,7 @@ Tab::clearDestination() {
   ui->output->setText(Q(""));
   setDestination(Q(""));
   m_config.m_destinationAuto.clear();
+  m_config.m_destinationUniquenessSuffix.clear();
 }
 
 void
@@ -626,18 +627,28 @@ Tab::onCopyTitleToOutputFileName() {
   if (!hasTitle())
     return;
 
-  auto info        = QFileInfo{ m_config.m_destination };
-  auto suffix      = info.suffix();
-  auto path        = info.path();
-  auto newFileName = m_config.m_title;
+  m_config.m_destinationUniquenessSuffix.clear();
 
-  if (!path.isEmpty())
-    newFileName = Q("%1/%2").arg(path).arg(newFileName);
+  auto info = QFileInfo{ m_config.m_destination };
+  auto path = info.path();
 
-  if (suffix.isEmpty())
-    suffix = "mkv";
+  QString newFileName;
 
-  ui->output->setText(QDir::toNativeSeparators(Q("%1.%2").arg(newFileName).arg(suffix)));
+  if (Util::Settings::get().m_uniqueOutputFileNames)
+    newFileName = generateUniqueOutputFileName(m_config.m_title, QDir{path});
+
+  else {
+    if (!path.isEmpty())
+      newFileName = Q("%1/%2").arg(path).arg(newFileName);
+
+    auto suffix = info.suffix();
+    if (suffix.isEmpty())
+      suffix = "mkv";
+
+    newFileName = Q("%1.%2").arg(newFileName).arg(suffix);
+  }
+
+  ui->output->setText(QDir::toNativeSeparators(newFileName));
 }
 
 bool
@@ -700,9 +711,10 @@ Tab::showRecentlyUsedOutputDirs() {
 
 void
 Tab::changeOutputDirectoryTo(QString const &directory) {
+  auto makeUnique  = Util::Settings::get().m_uniqueOutputFileNames;
   auto oldFileName = QFileInfo{ m_config.m_destination }.fileName();
   auto newFileName = !oldFileName.isEmpty() ? oldFileName : Q("%1.%2").arg(QY("unnamed")).arg(suggestOutputFileNameExtension());
-  auto newFilePath = Q("%1/%2").arg(directory).arg(newFileName);
+  auto newFilePath = makeUnique ? generateUniqueOutputFileName(QFileInfo{newFileName}.completeBaseName(), QDir{directory}) : Q("%1/%2").arg(directory).arg(newFileName);
 
   ui->output->setText(QDir::toNativeSeparators(newFilePath));
 }
