@@ -20,7 +20,7 @@ class MuxConfig;
 class Tab;
 
 class Tool : public ToolBase {
-  Q_OBJECT;
+  Q_OBJECT
 
 protected:
   // UI stuff:
